<?php

declare(strict_types=1);

namespace Drupal\cision\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\media\Entity\Media;

/**
 * Provides a cision form.
 */
final class CisionSettingsForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'cision_cision_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {

    $form['placeholder_image_id'] = [
      '#type' => 'number',
      '#title' => $this->t('Placeholder Image ID'),
      '#default_value' => $this->configFactory()->get('cision.settings')->get('placeholder_image_id'),
      '#required' => TRUE,
    ];

    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    if (!Media::load($form_state->getValue('placeholder_image_id'))) {
      $form_state->setErrorByName('placeholder_image_id', $this->t('No image with that id found.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->configFactory()->getEditable('cision.settings')
      ->set('placeholder_image_id', $form_state->getValue('placeholder_image_id'))
      ->save();
  }

}
